CheckoutTransactionsItem class

Object model for CheckoutTransactionsItem from the SumUp API spec.

Constructors

CheckoutTransactionsItem()
const
CheckoutTransactionsItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() CheckoutTransactionsItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override