CreateReaderTerminateError class

Error description

Constructors

CreateReaderTerminateError({required CreateReaderTerminateErrorErrors errors})
const
CreateReaderTerminateError.fromJson(Map<String, dynamic> json)
factory

Properties

errors CreateReaderTerminateErrorErrors
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({CreateReaderTerminateErrorErrors? errors}) CreateReaderTerminateError
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override