MembershipStatus enum
The status of the membership.
Values
- accepted → const MembershipStatus
-
const MembershipStatus('accepted') - pending → const MembershipStatus
-
const MembershipStatus('pending') - expired → const MembershipStatus
-
const MembershipStatus('expired') - disabled → const MembershipStatus
-
const MembershipStatus('disabled') - unknown → const MembershipStatus
-
const MembershipStatus('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String json) → MembershipStatus
Constants
-
values
→ const List<
MembershipStatus> - A constant List of the values in this enum, in order of their declaration.