Oauth2Security class

Constructors

Oauth2Security({String? accessToken, Future<String> tokenProvider(Iterable<String> scopes)?, Set<String> scopes = const {}})

Properties

accessToken String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes Set<String>
final
tokenProvider Future<String> Function(Iterable<String> scopes)?
final

Methods

createInterceptor() → Interceptor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited