OffsetPaginatedResponse<T> class

Inheritance

Constructors

OffsetPaginatedResponse({required List<T> items, required int total, required int offset, required int limit, Future<OffsetPaginatedResponse<T>?> fetchNext(int nextOffset)?})

Properties

fetchNext Future<OffsetPaginatedResponse<T>?> Function(int nextOffset)?
final
hashCode int
The hash code for this object.
no setterinherited
items List<T>
final
limit int
final
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final

Methods

getNextPage() Future<OffsetPaginatedResponse<T>?>
override
hasNextPage() bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited