Problem class

A RFC 9457 problem details object.

Additional properties specific to the problem type may be present.

Constructors

Problem({required Uri type_, String? title, int? status, String? detail, Uri? instance})
const
Problem.fromJson(Map<String, dynamic> json)
factory

Properties

detail String?
final
hashCode int
The hash code for this object.
no setteroverride
instance Uri?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
title String?
final
type_ Uri
final

Methods

copyWith({Uri? type_, String? title, int? status, String? detail, Uri? instance}) Problem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override