ProcessCheckoutGooglePay class
Raw PaymentData object received from Google Pay. Send the Google Pay response payload as-is.
Constructors
- ProcessCheckoutGooglePay()
-
const
-
ProcessCheckoutGooglePay.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
) → ProcessCheckoutGooglePay -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override