ReceiptMerchantDataMerchantProfile class

Merchant profile details displayed on the receipt.

Constructors

ReceiptMerchantDataMerchantProfile({String? merchantCode, String? businessName, String? companyRegistrationNumber, String? vatId, String? website, String? email, String? language, ReceiptMerchantDataMerchantProfileAddress? address})
const
ReceiptMerchantDataMerchantProfile.fromJson(Map<String, dynamic> json)
factory

Properties

address ReceiptMerchantDataMerchantProfileAddress?
final
businessName String?
final
companyRegistrationNumber String?
final
email String?
final
hashCode int
The hash code for this object.
no setteroverride
language String?
final
merchantCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vatId String?
final
website String?
final

Methods

copyWith({String? merchantCode, String? businessName, String? companyRegistrationNumber, String? vatId, String? website, String? email, String? language, ReceiptMerchantDataMerchantProfileAddress? address}) ReceiptMerchantDataMerchantProfile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override