TransactionsApi class

Constructors

TransactionsApi({required Dio dio, String? baseUrl})
const

Properties

baseUrl String?
final
dio → Dio
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTransactionV21({required String merchantCode, String? id, String? transactionCode, String? foreignTransactionId, String? clientTransactionId, CancelToken? cancelToken, Map<String, dynamic>? extra, Options? options}) Future<GetTransactionV21Result>
Retrieves the full details of an identified transaction. The transaction resource is identified by a query parameter and one of following parameters is required:
listTransactionsV21({required String merchantCode, String? transactionCode, Order? order, int? limit, List<String>? users, List<StatusesItem>? statuses, List<PaymentType>? paymentTypes, List<EntryMode>? entryModes, List<TypesItem>? types, DateTime? changesSince, DateTime? newestTime, String? newestRef, DateTime? oldestTime, String? oldestRef, CancelToken? cancelToken, Map<String, dynamic>? extra, Options? options}) Future<ListTransactionsV21Result>
Lists detailed history of all transactions associated with the merchant profile.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refundTransaction({required String merchantCode, required String id, RefundTransactionBodyApplicationJson? refundTransactionBodyApplicationJson, CancelToken? cancelToken, Map<String, dynamic>? extra, Options? options}) Future<RefundTransactionResult>
Refunds an identified transaction either in full or partially.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited