UpdateCustomerBodyApplicationJson class
Object model for UpdateCustomerBodyApplicationJson from the SumUp API spec.
Constructors
- UpdateCustomerBodyApplicationJson({PersonalDetails? personalDetails})
-
const
-
UpdateCustomerBodyApplicationJson.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- personalDetails → PersonalDetails?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{PersonalDetails? personalDetails}) → UpdateCustomerBodyApplicationJson -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override