UpdateCustomerResultError class
- Inheritance
-
- Object
- UpdateCustomerResult
- UpdateCustomerResultError
Constructors
- UpdateCustomerResultError(Response response)
-
const
- UpdateCustomerResultError.fromResponse(Response response)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- response → Response
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited