Event class
High-level transaction event details.
Constructors
Properties
- amount → double?
-
final
- deductedAmount → double?
-
final
- deductedFeeAmount → double?
-
final
- feeAmount → double?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- installmentNumber → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → EventStatus?
-
final
- timestamp → DateTime?
-
final
- transactionId → String?
-
final
- type_ → EventType?
-
final
Methods
-
copyWith(
{int? id, String? transactionId, EventType? type_, EventStatus? status, double? amount, DateTime? timestamp, double? feeAmount, int? installmentNumber, double? deductedAmount, double? deductedFeeAmount}) → Event -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override