MembershipResource class
Information about the resource the membership is in.
Constructors
- MembershipResource({required String id, required String type_, required String name, Uri? logo, required DateTime createdAt, required DateTime updatedAt, Attributes? attributes})
-
const
-
MembershipResource.fromJson(Map<
String, dynamic> json) -
factory
Properties
- attributes → Attributes?
-
final
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- logo → Uri?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type_ → String
-
final
- updatedAt → DateTime
-
final
Methods
-
copyWith(
{String? id, String? type_, String? name, Uri? logo, DateTime? createdAt, DateTime? updatedAt, Attributes? attributes}) → MembershipResource -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override