TransactionsApi class
Methods
getTransactionV21 ({required String merchantCode , String ? id , String ? transactionCode , String ? foreignTransactionId , String ? clientTransactionId , CancelToken? cancelToken , Options? options })
→ Future <GetTransactionV21Result >
Retrieves the full details of an identified transaction. The transaction resource is identified by a query parameter and one of following parameters is required:
listTransactionsV21 ({required String merchantCode , String ? transactionCode , Order ? order , int ? limit , List <String > ? users , List <StatusesItem > ? statuses , List <PaymentType > ? paymentTypes , List <EntryMode > ? entryModes , List <TypesItem > ? types , DateTime ? changesSince , DateTime ? newestTime , String ? newestRef , DateTime ? oldestTime , String ? oldestRef , CancelToken? cancelToken , Options? options })
→ Future <ListTransactionsV21Result >
Lists detailed history of all transactions associated with the merchant profile.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refundTransaction ({required String merchantCode , required String id , RefundTransactionBodyApplicationJson ? refundTransactionBodyApplicationJson , CancelToken? cancelToken , Options? options })
→ Future <RefundTransactionResult >
Refunds an identified transaction either in full or partially.
toString ()
→ String
A string representation of this object.
inherited